@@ -1,25 +1,25 @@
 from mock import MagicMock
 
-from django.test import TestCase
 from django.core.exceptions import ImproperlyConfigured
-from django.forms.widgets import HiddenInput
+from django.test import TestCase
 
 from wagtail.wagtailadmin.edit_handlers import (
     get_form_for_model,
     extract_panel_definitions_from_model_class,
     BaseFieldPanel,
     FieldPanel,
-    RichTextFieldPanel,
-    EditHandler,
     WagtailAdminModelForm,
     BaseTabbedInterface,
     TabbedInterface,
     BaseObjectList,
     ObjectList,
     PageChooserPanel,
-    InlinePanel
+    InlinePanel,
 )
+
+from wagtail.wagtailadmin.widgets import AdminPageChooser
 from wagtail.wagtailcore.models import Page, Site
+from wagtail.tests.models import PageChooserModel
 
 
 class TestGetFormForModel(TestCase):
@@ -63,9 +63,6 @@ class TestExtractPanelDefinitionsFromModelClass(TestCase):
 class TestTabbedInterface(TestCase):
     class FakeChild(object):
         class FakeGrandchild(object):
-            def render_js(self):
-                return "rendered js"
-
             def rendered_fields(self):
                 return ["rendered fields"]
 
@@ -101,10 +98,6 @@ class TestTabbedInterface(TestCase):
         result = self.tabbed_interface.render()
         self.assertIn('<div class="tab-content">', result)
 
-    def test_render_js(self):
-        result = self.tabbed_interface.render_js()
-        self.assertEqual(result, 'rendered js')
-
     def test_rendered_fields(self):
         result = self.tabbed_interface.rendered_fields()
         self.assertEqual(result, ["rendered fields"])
@@ -149,17 +142,6 @@ class TestFieldPanel(TestCase):
         self.assertIn('<p class="error-message">',
                       result)
 
-    def test_render_js_unknown_widget(self):
-        field = self.FakeField()
-        bound_field = self.FakeField()
-        widget = self.FakeField()
-        field.widget = widget
-        bound_field.field = field
-        self.field_panel.bound_field = bound_field
-        result = self.field_panel.render_js()
-        self.assertEqual(result,
-                         '')
-
     def test_render_as_field(self):
         field = self.FakeField()
         bound_field = self.FakeField()
@@ -194,10 +176,6 @@ class TestFieldPanel(TestCase):
         result = FieldPanel('barbecue', 'snowman').get_form_class(Page)
         self.assertTrue(issubclass(result, WagtailAdminModelForm))
 
-    def test_render_js(self):
-        result = self.field_panel.render_js()
-        self.assertEqual(result, "")
-
     def test_render_missing_fields(self):
         fake_form = self.FakeForm()
         fake_form["foo"] = "bar"
@@ -211,59 +189,33 @@ class TestFieldPanel(TestCase):
         self.assertIn("bar", self.field_panel.render_form_content())
 
 
-class TestRichTextFieldPanel(TestCase):
-    class FakeField(object):
-        label = 'label'
-        help_text = 'help text'
-        errors = ['errors']
-        id_for_label = 'id for label'
-
-    def test_render_js(self):
-        fake_field = self.FakeField()
-        rich_text_field_panel = RichTextFieldPanel('barbecue')(
-            instance=True,
-            form={'barbecue': fake_field})
-        result = rich_text_field_panel.render_js()
-        self.assertEqual(result,
-                         "makeRichTextEditable(fixPrefix('id for label'));")
-
-
 class TestPageChooserPanel(TestCase):
-    class FakeField(object):
-        label = 'label'
-        help_text = 'help text'
-        errors = ['errors']
-        id_for_label = 'id for label'
-
-    class FakeInstance(object):
-        class FakePage(object):
-            class FakeParent(object):
-                id = 1
-
-            name = 'fake page'
-
-            def get_parent(self):
-                return self.FakeParent()
-
-        def __init__(self):
-            fake_page = self.FakePage()
-            self.barbecue = fake_page
 
     def setUp(self):
-        fake_field = self.FakeField()
-        fake_instance = self.FakeInstance()
-        self.page_chooser_panel = PageChooserPanel('barbecue')(
-            instance=fake_instance,
-            form={'barbecue': fake_field})
+        model = PageChooserModel
+        self.chosen_page = Page.objects.get(pk=2)
+        test_instance = model.objects.create(page=self.chosen_page)
+        self.dotted_model = model._meta.app_label + '.' + model._meta.model_name
 
-    def test_render_js(self):
-        result = self.page_chooser_panel.render_js()
-        self.assertEqual(result,
-                         "createPageChooser(fixPrefix('id for label'), 'wagtailcore.page', 1);")
+        self.page_chooser_panel_class = PageChooserPanel('page', model)
+
+        form_class = get_form_for_model(model, widgets=self.page_chooser_panel_class.widget_overrides())
+        form = form_class(instance=test_instance)
+        form.errors['page'] = form.error_class(['errors'])
+
+        self.page_chooser_panel = self.page_chooser_panel_class(instance=test_instance,
+                                                                form=form)
+
+    def test_render_js_init(self):
+        result = self.page_chooser_panel.render_as_field()
+        self.assertIn(
+            'createPageChooser("{id}", "{model}", {parent});'.format(
+                id="id_page", model=self.dotted_model, parent=self.chosen_page.get_parent().id),
+            result)
 
     def test_get_chosen_item(self):
         result = self.page_chooser_panel.get_chosen_item()
-        self.assertEqual(result.name, 'fake page')
+        self.assertEqual(result, self.chosen_page)
 
     def test_render_as_field(self):
         result = self.page_chooser_panel.render_as_field()
@@ -272,7 +224,7 @@ class TestPageChooserPanel(TestCase):
 
     def test_widget_overrides(self):
         result = self.page_chooser_panel.widget_overrides()
-        self.assertEqual(result, {'barbecue': HiddenInput})
+        self.assertIsInstance(result['page'], AdminPageChooser)
 
     def test_target_content_type(self):
         result = PageChooserPanel(
@@ -347,9 +299,6 @@ class TestInlinePanel(TestCase):
         name = 'mock panel'
 
         class FakeChild(object):
-            def render_js(self):
-                return "rendered js"
-
             def rendered_fields(self):
                 return ["rendered fields"]
 
@@ -407,10 +356,10 @@ class TestInlinePanel(TestCase):
             form=self.fake_field)
         self.assertIn('Add foo', inline_panel.render())
 
-    def test_render_js(self):
+    def test_render_js_init(self):
         inline_panel = InlinePanel(self.mock_model,
                                    'formset')(
             instance=self.fake_instance,
             form=self.fake_field)
         self.assertIn('var panel = InlinePanel({',
-                      inline_panel.render_js())
+                      inline_panel.render_js_init())
