@@ -1,4 +1,8 @@
+from __future__ import absolute_import, unicode_literals
+
+import json
 import django
+
 from django.db import models
 from django.forms import Textarea
 
@@ -7,9 +11,10 @@ if django.VERSION < (1, 7):
     add_introspection_rules([], ["^wagtail\.wagtailcore\.fields\.RichTextField"])
 
 from wagtail.wagtailcore.rich_text import DbWhitelister, expand_db_html
+from wagtail.utils.widgets import WidgetWithScript
 
 
-class RichTextArea(Textarea):
+class RichTextArea(WidgetWithScript, Textarea):
     def get_panel(self):
         from wagtail.wagtailadmin.edit_handlers import RichTextFieldPanel
         return RichTextFieldPanel
@@ -21,6 +26,9 @@ class RichTextArea(Textarea):
             translated_value = expand_db_html(value, for_editor=True)
         return super(RichTextArea, self).render(name, translated_value, attrs)
 
+    def render_js_init(self, id_, name, value):
+        return "makeRichTextEditable({0});".format(json.dumps(id_))
+
     def value_from_datadict(self, data, files, name):
         original_value = super(RichTextArea, self).value_from_datadict(data, files, name)
         if original_value is None:
